      subroutine hec_online_his
c
c book online histograms 
c
      implicit none
c
      include'hec_par.inc'
c
c common for datacard values
c
      include'hec_datacard.inc'
c
c geometry correspondence tables common
c must be preceded by the include file hec_par.inc
c
      include'hec_geo.inc'
c
c online common
c
      include'hec_online.inc'
c
c online histogram id common
c
      include'hec_online_his.inc'
c
c pedestal 
c
      include'hec_ped.inc'
c
c run header common
c
      include'hec_runh.inc'
c
c local variables
c
      integer i_z, ic
      character*70 ct
      character*1 cd
      character*4 c4
      real rmsmax
      real vmax
      integer nbin
      integer id
c
c check run header to see if adc banks were turned on in this run
c
      call hec_runh_pass
      if (.not. calo_on_flag) then
        print *,'***The ADCs are turned off in run header,', 
     +          'skipping several histograms'
        return 
      endif
c
c zero our moments array
c
      call vzero(adcmom,i_adc_dim*i_tim_dim*3)
c
c set flag for first pass though analysis (to allow new histogram file)
c
      print *, ' ***booking online histograms'
c
c reset the number of histogram ids used
c
      n_id_used = 0
c
c adc pedestal values
c
      id = id_ped
      n_id_used = n_id_used + 1
      id_used(n_id_used) = id
      call hbook1(id, 'adc pedestals', 100, 500., 1500., 0.)
c
      id = id_ped_ic
      n_id_used = n_id_used + 1
      id_used(n_id_used) = id
      call hbook1(id, 'adc pedestals vs ic', i_adc_used, 
     +0.5, i_adc_used + 0.5, 0.)
c
c adc pedestal rms values 
c
      nbin = 100
      rmsmax = 
     +real(max(100, 100*(int(vmax(adc_rms, i_adc_used)/100.) + 1)))
      id = id_rms
      n_id_used = n_id_used + 1
      id_used(n_id_used) = id
      call hbook1(id, 'adc pedestals rms', nbin, 0., rmsmax, 0.)
c
      id = id_rms_ic
      n_id_used = n_id_used + 1
      id_used(n_id_used) = id
      call hbook1(id, 'adc pedestals rms vs ic', i_adc_used, 
     +0.5, i_adc_used + 0.5, 0.)
c
c maximum versus channel number
c
      nbin = i_adc_used
      ct = 'ave. adc(max) vs. channel number '//cd
      id = id_max_ic
      call hbook2(id,ct,nbin,0.5,i_adc_used+0.5,100,500.,5000,1)
c
c book lego map of front face to find beam 
c do 2x6 lego plot to represent first 12 pads
c
      nbin = 2
      ct = 'map of max values in pads on front face'//cd
      id = id_map
      call hbook2(id,ct,2,0.5,2.5,6,0.5,6.5,100000.)
c
c adc(max)-ped distribution for each tower depth
c
      nbin = 100
      do i_z = 1, i_z_used
        write(cd, '(i1)') i_z
        ct = 'adc(max) - ped for tower depth '//cd
        id = id_adc_z + i_z
        n_id_used = n_id_used + 1
        id_used(n_id_used) = id
        call hbook1(id, ct, nbin, 0., 5000., 0.)
ccc        call hbook1(id, ct, nbin, 1., -1., 0.)
      enddo
c
c adc(max)-ped distribution for each channel
c
      nbin = 100
      do ic = 1, i_adc_used
        write(c4, '(i4)') ic
        ct = 'adc(max) - ped for channel '//c4
        id = id_adc_ic + ic
        n_id_used = n_id_used + 1
        id_used(n_id_used) = id
        call hbook1(id, ct, nbin, 0., 2000., 0.)
      enddo
c
c time(max) distribution for each channel for 1997
c
      if (irunpd .ge. 4) then
        nbin = 100
        do ic = 1, i_adc_used
          write(c4, '(i4)') ic
          ct = 'time(max) for channel '//c4//' (time slice)'
          id = id_tim_ic + ic
          n_id_used = n_id_used + 1
          id_used(n_id_used) = id
          call hbook1(id, ct, nbin, 0.5 , i_tim_used+0.5 , 0.)
ccc          call hbook1(id, ct, nbin, 1., -1., 0.)
        enddo
      endif
c
c time profile for each channel in 1997
c
      if (irunpd .ge. 4) then
        do ic = 1, i_adc_used
          write(c4, '(i4)') ic
          ct = 'time profile for channel '//c4
          id = id_tprof_ic + ic
          n_id_used = n_id_used + 1
          id_used(n_id_used) = id
            call hbook1(id,ct,i_tim_used,0.5,real(i_tim_used)+0.5,0.)
        enddo
      endif
c
c calibrated energy for each channel, if calibration is turned on
c
      nbin = 100
      do ic = 1, i_adc_used
        write(c4, '(i4)') ic
        ct = 'energy in nA for channel '//c4
        id = id_cal_ic + ic
        n_id_used = n_id_used + 1
        id_used(n_id_used) = id
        call hbook1(id, ct, nbin, 1., -1., 0.)  
      enddo
c
c calibrated energy if above sigma cut
c
      ct = 'energy in nA for channels above 1 sigma '
      id = id_cal_ic + 1001
      call hbook1(id, ct, nbin, 1., -1., 0.)  
      ct = 'energy in nA for channels above 2 sigma '
      id = id_cal_ic + 1002
      call hbook1(id, ct, nbin, 1., -1., 0.)  
      ct = 'energy in nA for channels above 3 sigma '
      id = id_cal_ic + 1003
      call hbook1(id, ct, nbin, 1., -1., 0.)  
c
c fadc  histograms (8 fadc channels)
c
      do ic = 1, i_fa_cdim 
         write(c4, '(i4)') ic
         ct = 'fadc counts in channel '//c4
         id = id_fadc + ic
         call hbook1(id, ct, 100, 0.5, 100.5, 0.)
      enddo           
c
      print *, ' ***End of online histogram booking'
      end













